Shape-Link
==========

|PyPI Version| |Tests| |Coverage Status|


Write your own plug-in for real-time data processing with Shape-In.


Documentation
-------------
The documentation is available at
`shapelink.readthedocs.io <https://shapelink.readthedocs.io>`__.


Installation
------------
Install with pip:
::

    pip install shapelink


Testing
-------
Running tests

::

    python setup.py test



.. |PyPI Version| image:: https://img.shields.io/pypi/v/shapelink.svg
   :target: https://pypi.python.org/pypi/shapelink
.. |Tests| image:: https://img.shields.io/github/workflow/status/ZELLMECHANIK-DRESDEN/shapelink/Checks
   :target: https://github.com/ZELLMECHANIK-DRESDEN/shapelink/actions?query=workflow%3A%22Checks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/ZELLMECHANIK-DRESDEN/shapelink/main.svg
   :target: https://codecov.io/gh/ZELLMECHANIK-DRESDEN/shapelink

